@@ -18,7 +18,7 @@
 // Copyright (C) 2005, 2006 Kristian Høgsberg <krh@redhat.com>
 // Copyright (C) 2005 Nickolay V. Shmyrev <nshmyrev@yandex.ru>
 // Copyright (C) 2006-2011, 2013 Carlos Garcia Campos <carlosgc@gnome.org>
-// Copyright (C) 2008, 2009, 2011-2017 Adrian Johnson <ajohnson@redneon.com>
+// Copyright (C) 2008, 2009, 2011-2017, 2022 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2008 Michael Vrable <mvrable@cs.ucsd.edu>
 // Copyright (C) 2010-2013 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2015 Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
@@ -118,21 +118,36 @@ public:
     // radialShadedFill()?  If this returns false, these shaded fills
     // will be reduced to a series of other drawing operations.
 #if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 12, 0)
-    bool useShadedFills(int type) override { return type <= 7; }
+    bool useShadedFills(int type) override
+    {
+        return type <= 7;
+    }
 #else
-    bool useShadedFills(int type) override { return type > 1 && type < 4; }
+    bool useShadedFills(int type) override
+    {
+        return type > 1 && type < 4;
+    }
 #endif
 
     // Does this device use FillColorStop()?
-    bool useFillColorStop() override { return true; }
+    bool useFillColorStop() override
+    {
+        return true;
+    }
 
     // Does this device use beginType3Char/endType3Char?  Otherwise,
     // text in Type 3 fonts will be drawn with drawChar/drawString.
-    bool interpretType3Chars() override { return false; }
+    bool interpretType3Chars() override
+    {
+        return false;
+    }
 
     // Does this device need to clip pages to the crop box even when the
     // box is the crop box?
-    bool needClipToCropBox() override { return true; }
+    bool needClipToCropBox() override
+    {
+        return true;
+    }
 
     //----- initialization and control
 
@@ -230,7 +245,13 @@ public:
     // Called to indicate that a new PDF document has been loaded.
     void startDoc(PDFDoc *docA, CairoFontEngine *fontEngine = nullptr);
 
-    bool isReverseVideo() { return false; }
+    // Called to prepare this output dev for rendering CairoType3Font.
+    void startType3Render(GfxState *state, XRef *xref);
+
+    bool isReverseVideo()
+    {
+        return false;
+    }
 
     void setCairo(cairo_t *cr);
     void setTextPage(TextPage *text);
@@ -241,14 +262,27 @@ public:
     }
     void copyAntialias(cairo_t *cr, cairo_t *source_cr);
 
-    void setInType3Char(bool inType3CharA) { inType3Char = inType3CharA; }
+    void setInType3Char(bool inType3CharA)
+    {
+        inType3Char = inType3CharA;
+    }
     void getType3GlyphWidth(double *wx, double *wy)
     {
         *wx = t3_glyph_wx;
         *wy = t3_glyph_wy;
     }
-    bool hasType3GlyphBBox() { return t3_glyph_has_bbox; }
-    double *getType3GlyphBBox() { return t3_glyph_bbox; }
+    bool hasType3GlyphBBox()
+    {
+        return t3_glyph_has_bbox;
+    }
+    double *getType3GlyphBBox()
+    {
+        return t3_glyph_bbox;
+    }
+    bool type3GlyphHasColor()
+    {
+        return t3_glyph_has_color;
+    }
 
 protected:
     void doPath(cairo_t *cairo, GfxState *state, const GfxPath *path);
@@ -266,14 +300,14 @@ protected:
     bool setMimeDataForCCITTParams(Stream *str, cairo_surface_t *image, int height);
 #endif
 
-    GfxRGB fill_color, stroke_color;
+    std::optional<GfxRGB> fill_color, stroke_color;
     cairo_pattern_t *fill_pattern, *stroke_pattern;
     double fill_opacity;
     double stroke_opacity;
     bool stroke_adjust;
     bool adjusted_stroke_width;
     bool align_stroke_coords;
-    CairoFont *currentFont;
+    std::shared_ptr<CairoFont> currentFont;
     XRef *xref;
 
     struct StrokePathClip
@@ -316,6 +350,8 @@ protected:
     bool inType3Char; // inside a Type 3 CharProc
     double t3_glyph_wx, t3_glyph_wy;
     bool t3_glyph_has_bbox;
+    bool t3_glyph_has_color;
+    bool has_color;
     double t3_glyph_bbox[4];
     bool prescaleImages;
 
@@ -336,12 +372,17 @@ protected:
         struct ColorSpaceStack *next;
     } * groupColorSpaceStack;
 
-    struct MaskStack
+    struct SaveStateElement
     {
-        cairo_pattern_t *mask;
+        // These patterns hold a reference
+        cairo_pattern_t *fill_pattern;
+        cairo_pattern_t *stroke_pattern;
+        double fill_opacity;
+        double stroke_opacity;
+        cairo_pattern_t *mask; // can be null
         cairo_matrix_t mask_matrix;
-        struct MaskStack *next;
-    } * maskStack;
+    };
+    std::vector<SaveStateElement> saveStateStack;
 };
 
 //------------------------------------------------------------------------
@@ -376,20 +417,35 @@ public:
     // radialShadedFill()?  If this returns false, these shaded fills
     // will be reduced to a series of other drawing operations.
 #if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 11, 2)
-    bool useShadedFills(int type) override { return type <= 7; }
+    bool useShadedFills(int type) override
+    {
+        return type <= 7;
+    }
 #else
-    bool useShadedFills(int type) override { return type < 4; }
+    bool useShadedFills(int type) override
+    {
+        return type < 4;
+    }
 #endif
 
     // Does this device use FillColorStop()?
-    bool useFillColorStop() override { return false; }
+    bool useFillColorStop() override
+    {
+        return false;
+    }
 
     // Does this device use beginType3Char/endType3Char?  Otherwise,
     // text in Type 3 fonts will be drawn with drawChar/drawString.
-    bool interpretType3Chars() override { return false; }
+    bool interpretType3Chars() override
+    {
+        return false;
+    }
 
     // Does this device need non-text content?
-    bool needNonText() override { return true; }
+    bool needNonText() override
+    {
+        return true;
+    }
 
     //----- save/restore graphics state
     void saveState(GfxState *state) override { }
@@ -419,9 +475,18 @@ public:
     void fill(GfxState *state) override { }
     void eoFill(GfxState *state) override { }
     void clipToStrokePath(GfxState *state) override { }
-    bool tilingPatternFill(GfxState *state, Gfx *gfx, Catalog *cat, GfxTilingPattern *tPat, const double *mat, int x0, int y0, int x1, int y1, double xStep, double yStep) override { return true; }
-    bool axialShadedFill(GfxState *state, GfxAxialShading *shading, double tMin, double tMax) override { return true; }
-    bool radialShadedFill(GfxState *state, GfxRadialShading *shading, double sMin, double sMax) override { return true; }
+    bool tilingPatternFill(GfxState *state, Gfx *gfx, Catalog *cat, GfxTilingPattern *tPat, const double *mat, int x0, int y0, int x1, int y1, double xStep, double yStep) override
+    {
+        return true;
+    }
+    bool axialShadedFill(GfxState *state, GfxAxialShading *shading, double tMin, double tMax) override
+    {
+        return true;
+    }
+    bool radialShadedFill(GfxState *state, GfxRadialShading *shading, double sMin, double sMax) override
+    {
+        return true;
+    }
 
     //----- path clipping
     void clip(GfxState *state) override { }
@@ -451,8 +516,14 @@ public:
         imgDrawCbkData = data;
     }
     // Iterate through list of images.
-    int getNumImages() const { return numImages; }
-    CairoImage *getImage(int i) const { return images[i]; }
+    int getNumImages() const
+    {
+        return numImages;
+    }
+    CairoImage *getImage(int i) const
+    {
+        return images[i];
+    }
 
 private:
     void saveImage(CairoImage *image);
