@@ -45,6 +45,7 @@
 // Copyright (C) 2021, 2022 Stefan Löffler <st.loeffler@gmail.com>
 // Copyright (C) 2021 sunderme <sunderme@gmx.de>
 // Copyright (C) 2022 Even Rouault <even.rouault@spatialys.com>
+// Copyright (C) 2022 Claes Nästén <pekdon@gmail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -53,6 +54,7 @@
 
 #include <config.h>
 
+#include <algorithm>
 #include <cstring>
 #include <cstdio>
 #include <cctype>
@@ -78,9 +80,7 @@
 #    include <fontconfig/fontconfig.h>
 #endif
 
-#ifdef _MSC_VER
-#    define strcasecmp stricmp
-#else
+#ifndef _MSC_VER
 #    include <strings.h>
 #endif
 
@@ -92,6 +92,9 @@
 #include "UnicodeMapTables.h"
 #include "UnicodeMapFuncs.h"
 
+#include "fofi/FoFiTrueType.h"
+#include "fofi/FoFiIdentifier.h"
+
 //------------------------------------------------------------------------
 
 #define cidToUnicodeCacheSize 4
@@ -253,11 +256,16 @@ public:
     SysFontList &operator=(const SysFontList &) = delete;
     const SysFontInfo *find(const std::string &name, bool isFixedWidth, bool exact);
 
+    const std::vector<SysFontInfo *> &getFonts() const { return fonts; }
+
 #ifdef _WIN32
-    void scanWindowsFonts(GooString *winFontDir);
+    void scanWindowsFonts(const std::string &winFontDir);
 #endif
 #ifdef WITH_FONTCONFIGURATION_FONTCONFIG
-    void addFcFont(SysFontInfo *si) { fonts.push_back(si); }
+    void addFcFont(SysFontInfo *si)
+    {
+        fonts.push_back(si);
+    }
 #endif
 private:
 #ifdef _WIN32
@@ -658,22 +666,20 @@ FILE *GlobalParams::findToUnicodeFile(const GooString *name)
 }
 
 #ifdef WITH_FONTCONFIGURATION_FONTCONFIG
-static bool findModifier(const char *name, const char *modifier, const char **start)
+static bool findModifier(const std::string &name, const size_t modStart, const char *modifier, size_t &start)
 {
-    const char *match;
-
-    if (name == nullptr) {
+    if (modStart == std::string::npos) {
         return false;
     }
 
-    match = strstr(name, modifier);
-    if (match) {
-        if (*start == nullptr || match < *start) {
-            *start = match;
+    size_t match = name.find(modifier, modStart);
+    if (match == std::string::npos) {
+        return false;
+    } else {
+        if (start == std::string::npos || match < start) {
+            start = match;
         }
         return true;
-    } else {
-        return false;
     }
 }
 
@@ -715,57 +721,55 @@ static const char *getFontLang(const GfxFont *font)
 static FcPattern *buildFcPattern(const GfxFont *font, const GooString *base14Name)
 {
     int weight = -1, slant = -1, width = -1, spacing = -1;
-    const char *family;
-    const char *start;
     FcPattern *p;
 
     // this is all heuristics will be overwritten if font had proper info
-    char *fontName = strdup(((base14Name == nullptr) ? font->getNameWithoutSubsetTag() : base14Name->toStr()).c_str());
+    std::string fontName;
+    if (base14Name == nullptr) {
+        fontName = font->getNameWithoutSubsetTag();
+    } else {
+        fontName = base14Name->toStr();
+    }
 
-    const char *modifiers = strchr(fontName, ',');
-    if (modifiers == nullptr) {
-        modifiers = strchr(fontName, '-');
+    size_t modStart = fontName.find(',');
+    if (modStart == std::string::npos) {
+        modStart = fontName.find('-');
     }
 
     // remove the - from the names, for some reason, Fontconfig does not
     // understand "MS-Mincho" but does with "MS Mincho"
-    const int len = strlen(fontName);
-    for (int i = 0; i < len; i++) {
-        fontName[i] = (fontName[i] == '-' ? ' ' : fontName[i]);
-    }
+    std::replace(fontName.begin(), fontName.end(), '-', ' ');
 
-    start = nullptr;
-    findModifier(modifiers, "Regular", &start);
-    findModifier(modifiers, "Roman", &start);
+    size_t start = std::string::npos;
+    findModifier(fontName, modStart, "Regular", start);
+    findModifier(fontName, modStart, "Roman", start);
 
-    if (findModifier(modifiers, "Oblique", &start)) {
+    if (findModifier(fontName, modStart, "Oblique", start)) {
         slant = FC_SLANT_OBLIQUE;
     }
-    if (findModifier(modifiers, "Italic", &start)) {
+    if (findModifier(fontName, modStart, "Italic", start)) {
         slant = FC_SLANT_ITALIC;
     }
-    if (findModifier(modifiers, "Bold", &start)) {
+    if (findModifier(fontName, modStart, "Bold", start)) {
         weight = FC_WEIGHT_BOLD;
     }
-    if (findModifier(modifiers, "Light", &start)) {
+    if (findModifier(fontName, modStart, "Light", start)) {
         weight = FC_WEIGHT_LIGHT;
     }
-    if (findModifier(modifiers, "Medium", &start)) {
+    if (findModifier(fontName, modStart, "Medium", start)) {
         weight = FC_WEIGHT_MEDIUM;
     }
-    if (findModifier(modifiers, "Condensed", &start)) {
+    if (findModifier(fontName, modStart, "Condensed", start)) {
         width = FC_WIDTH_CONDENSED;
     }
 
-    if (start) {
+    std::string family;
+    if (start == std::string::npos) {
+        family = fontName;
+    } else {
         // There have been "modifiers" in the name, crop them to obtain
         // the family name
-        family = strndup(fontName, modifiers - fontName);
-        free(fontName);
-        fontName = nullptr;
-    } else {
-        family = fontName;
-        fontName = nullptr;
+        family = fontName.substr(0, modStart);
     }
 
     // use font flags
@@ -779,12 +783,9 @@ static FcPattern *buildFcPattern(const GfxFont *font, const GooString *base14Nam
         slant = FC_SLANT_ITALIC;
     }
 
-    bool freeFamily = true;
     // if the FontDescriptor specified a family name use it
     if (font->getFamily()) {
-        free((char *)family);
-        family = font->getFamily()->c_str();
-        freeFamily = false;
+        family = font->getFamily()->toStr();
     }
 
     // if the FontDescriptor specified a weight use it
@@ -855,7 +856,7 @@ static FcPattern *buildFcPattern(const GfxFont *font, const GooString *base14Nam
 
     const char *lang = getFontLang(font);
 
-    p = FcPatternBuild(nullptr, FC_FAMILY, FcTypeString, family, FC_LANG, FcTypeString, lang, NULL);
+    p = FcPatternBuild(nullptr, FC_FAMILY, FcTypeString, family.c_str(), FC_LANG, FcTypeString, lang, NULL);
     if (slant != -1) {
         FcPatternAddInteger(p, FC_SLANT, slant);
     }
@@ -869,9 +870,6 @@ static FcPattern *buildFcPattern(const GfxFont *font, const GooString *base14Nam
         FcPatternAddInteger(p, FC_SPACING, spacing);
     }
 
-    if (freeFamily) {
-        free((char *)family);
-    }
     return p;
 }
 #endif
@@ -890,6 +888,43 @@ GooString *GlobalParams::findFontFile(const std::string &fontName)
     return path;
 }
 
+#if defined(WITH_FONTCONFIGURATION_FONTCONFIG) || defined(WITH_FONTCONFIGURATION_WIN32)
+
+static bool supportedFontForEmbedding(Unicode uChar, const char *filepath, int faceIndex)
+{
+    if (!GooString::endsWith(filepath, ".ttf") && !GooString::endsWith(filepath, ".ttc") && !GooString::endsWith(filepath, ".otf")) {
+        // for now we only support ttf, ttc, otf fonts
+        return false;
+    }
+
+    const FoFiIdentifierType fontFoFiType = FoFiIdentifier::identifyFile(filepath);
+    if (fontFoFiType != fofiIdTrueType && fontFoFiType != fofiIdTrueTypeCollection && fontFoFiType != fofiIdOpenTypeCFF8Bit && fontFoFiType != fofiIdOpenTypeCFFCID) {
+        // for now we only support ttf, ttc, otf fonts
+        return false;
+    }
+
+    const std::unique_ptr<FoFiTrueType> fft = FoFiTrueType::load(filepath, faceIndex);
+    if (!fft) {
+        error(errIO, -1, "Form::addFontToDefaultResources. Failed to FoFiTrueType::load {0:s}", filepath);
+        return false;
+    }
+
+    // Look for the Unicode BMP cmaps, which are 0/3 or 3/1
+    int unicodeBMPCMap = fft->findCmap(0, 3);
+    if (unicodeBMPCMap < 0) {
+        unicodeBMPCMap = fft->findCmap(3, 1);
+    }
+    if (unicodeBMPCMap < 0) {
+        // for now we only support files with unicode bmp cmaps
+        return false;
+    }
+
+    const int glyph = fft->mapCodeToGID(unicodeBMPCMap, uChar);
+    return glyph > 0;
+}
+
+#endif
+
 /* if you can't or don't want to use Fontconfig, you need to implement
    this function for your platform. For Windows, it's in GlobalParamsWin.cc
 */
@@ -1069,6 +1104,71 @@ fin:
     return path;
 }
 
+FamilyStyleFontSearchResult GlobalParams::findSystemFontFileForFamilyAndStyle(const std::string &fontFamily, const std::string &fontStyle)
+{
+    FcChar8 *fcFilePath = nullptr;
+    int faceIndex = 0;
+    FcPattern *p = FcPatternBuild(nullptr, FC_FAMILY, FcTypeString, fontFamily.c_str(), FC_STYLE, FcTypeString, fontStyle.c_str(), nullptr);
+    FcConfigSubstitute(nullptr, p, FcMatchPattern);
+    FcDefaultSubstitute(p);
+    if (p) {
+        FcResult res;
+        FcFontSet *set = FcFontSort(nullptr, p, FcFalse, nullptr, &res);
+        if (set) {
+            if (res == FcResultMatch && set->nfont > 0) {
+                FcPatternGetString(set->fonts[0], FC_FILE, 0, &fcFilePath);
+                FcPatternGetInteger(set->fonts[0], FC_INDEX, 0, &faceIndex);
+            }
+            FcFontSetDestroy(set);
+        }
+        FcPatternDestroy(p);
+    }
+
+    if (!fcFilePath) {
+        error(errIO, -1, "Couldn't find font file for {0:s} {1:s}", fontFamily.c_str(), fontStyle.c_str());
+        return {};
+    }
+
+    return FamilyStyleFontSearchResult(reinterpret_cast<char *>(fcFilePath), faceIndex);
+}
+
+UCharFontSearchResult GlobalParams::findSystemFontFileForUChar(Unicode uChar, const GfxFont &fontToEmulate)
+{
+    FcPattern *pattern = buildFcPattern(&fontToEmulate, nullptr);
+
+    FcConfigSubstitute(nullptr, pattern, FcMatchPattern);
+    FcDefaultSubstitute(pattern);
+
+    FcResult result = FcResultMatch;
+    FcFontSet *fontSet = FcFontSort(nullptr, pattern, FcFalse, nullptr, &result);
+    FcPatternDestroy(pattern);
+
+    if (fontSet) {
+        const std::unique_ptr<FcFontSet, void (*)(FcFontSet *)> fontSetDeleter(fontSet, [](FcFontSet *fSet) { FcFontSetDestroy(fSet); });
+        for (int i = 0; i < fontSet->nfont; i++) {
+            FcChar8 *fcFilePath = nullptr;
+            int faceIndex = 0;
+            FcChar8 *fcFamily = nullptr;
+            FcChar8 *fcStyle = nullptr;
+            FcPatternGetString(fontSet->fonts[i], FC_FILE, 0, &fcFilePath);
+            FcPatternGetInteger(fontSet->fonts[i], FC_INDEX, 0, &faceIndex);
+            FcPatternGetString(fontSet->fonts[i], FC_FAMILY, 0, &fcFamily);
+            FcPatternGetString(fontSet->fonts[i], FC_STYLE, 0, &fcStyle);
+            if (!fcFilePath || !fcFamily || !fcStyle) {
+                continue;
+            }
+
+            const char *filepath = reinterpret_cast<char *>(fcFilePath);
+
+            if (supportedFontForEmbedding(uChar, filepath, faceIndex)) {
+                return UCharFontSearchResult(filepath, faceIndex, reinterpret_cast<char *>(fcFamily), reinterpret_cast<char *>(fcStyle));
+            }
+        }
+    }
+
+    return {};
+}
+
 #elif defined(WITH_FONTCONFIGURATION_WIN32)
 #    include "GlobalParamsWin.cc"
 
@@ -1076,7 +1176,21 @@ GooString *GlobalParams::findBase14FontFile(const GooString *base14Name, const G
 {
     return findFontFile(base14Name->toStr());
 }
+
 #else
+
+FamilyStyleFontSearchResult GlobalParams::findSystemFontFileForFamilyAndStyle(const std::string &fontFamily, const std::string &fontStyle)
+{
+    error(errUnimplemented, -1, "GlobalParams::findSystemFontFileForFamilyAndStyle not implemented for this platform");
+    return {};
+}
+
+UCharFontSearchResult GlobalParams::findSystemFontFileForUChar(Unicode uChar, const GfxFont &fontToEmulate)
+{
+    error(errUnimplemented, -1, "GlobalParams::findSystemFontFileForUChar not implemented for this platform");
+    return {};
+}
+
 GooString *GlobalParams::findBase14FontFile(const GooString *base14Name, const GfxFont *font)
 {
     return findFontFile(base14Name->toStr());
