@@ -109,8 +109,9 @@ static bool isTableScopeName(Object *value)
 
 static bool isRGBColor(Object *value)
 {
-    if (!(value->isArray() && value->arrayGetLength() == 3))
+    if (!(value->isArray() && value->arrayGetLength() == 3)) {
         return false;
+    }
 
     bool okay = true;
     for (int i = 0; i < 3; i++) {
@@ -353,10 +354,12 @@ static bool ownerHasMorePriority(Attribute::Owner a, Attribute::Owner b)
     size_t aIndex, bIndex, i;
 
     for (i = aIndex = bIndex = 0; i < sizeof(ownerMap) / sizeof(ownerMap[0]); i++) {
-        if (ownerMap[i].owner == a)
+        if (ownerMap[i].owner == a) {
             aIndex = i;
-        if (ownerMap[i].owner == b)
+        }
+        if (ownerMap[i].owner == b) {
             bIndex = i;
+        }
     }
 
     return aIndex < bIndex;
@@ -442,8 +445,9 @@ static inline const AttributeMapEntry *getAttributeMapEntry(const AttributeMapEn
         const AttributeMapEntry *entry = *entryList;
         while (entry->type != Attribute::Unknown) {
             assert(entry->name);
-            if (type == entry->type)
+            if (type == entry->type) {
                 return entry;
+            }
             entry++;
         }
         entryList++;
@@ -458,8 +462,9 @@ static inline const AttributeMapEntry *getAttributeMapEntry(const AttributeMapEn
         const AttributeMapEntry *entry = *entryList;
         while (entry->type != Attribute::Unknown) {
             assert(entry->name);
-            if (strcmp(name, entry->name) == 0)
+            if (strcmp(name, entry->name) == 0) {
                 return entry;
+            }
             entry++;
         }
         entryList++;
@@ -470,8 +475,9 @@ static inline const AttributeMapEntry *getAttributeMapEntry(const AttributeMapEn
 static inline const OwnerMapEntry *getOwnerMapEntry(Attribute::Owner owner)
 {
     for (const OwnerMapEntry &entry : ownerMap) {
-        if (owner == entry.owner)
+        if (owner == entry.owner) {
             return &entry;
+        }
     }
     return nullptr;
 }
@@ -479,8 +485,9 @@ static inline const OwnerMapEntry *getOwnerMapEntry(Attribute::Owner owner)
 static inline const OwnerMapEntry *getOwnerMapEntry(const char *name)
 {
     for (const OwnerMapEntry &entry : ownerMap) {
-        if (strcmp(name, entry.name) == 0)
+        if (strcmp(name, entry.name) == 0) {
             return &entry;
+        }
     }
     return nullptr;
 }
@@ -500,8 +507,9 @@ static Attribute::Owner nameToOwner(const char *name)
 static inline const TypeMapEntry *getTypeMapEntry(StructElement::Type type)
 {
     for (const TypeMapEntry &entry : typeMap) {
-        if (type == entry.type)
+        if (type == entry.type) {
             return &entry;
+        }
     }
     return nullptr;
 }
@@ -509,18 +517,21 @@ static inline const TypeMapEntry *getTypeMapEntry(StructElement::Type type)
 static inline const TypeMapEntry *getTypeMapEntry(const char *name)
 {
     for (const TypeMapEntry &entry : typeMap) {
-        if (strcmp(name, entry.name) == 0)
+        if (strcmp(name, entry.name) == 0) {
             return &entry;
+        }
     }
     return nullptr;
 }
 
 static const char *typeToName(StructElement::Type type)
 {
-    if (type == StructElement::MCID)
+    if (type == StructElement::MCID) {
         return "MarkedContent";
-    if (type == StructElement::OBJR)
+    }
+    if (type == StructElement::OBJR) {
         return "ObjectReference";
+    }
 
     const TypeMapEntry *entry = getTypeMapEntry(type);
     return entry ? entry->name : "Unknown";
@@ -555,8 +566,9 @@ Attribute::Attribute(Type typeA, Object *valueA)
 
     value = valueA->copy();
 
-    if (!checkType())
+    if (!checkType()) {
         type = Unknown;
+    }
 }
 
 Attribute::~Attribute()
@@ -566,12 +578,14 @@ Attribute::~Attribute()
 
 const char *Attribute::getTypeName() const
 {
-    if (type == UserProperty)
+    if (type == UserProperty) {
         return name.c_str();
+    }
 
     const AttributeMapEntry *entry = getAttributeMapEntry(attributeMapAll, type);
-    if (entry)
+    if (entry) {
         return entry->name;
+    }
 
     return "Unknown";
 }
@@ -590,10 +604,11 @@ Object *Attribute::getDefaultValue(Attribute::Type type)
 void Attribute::setFormattedValue(const char *formattedA)
 {
     if (formattedA) {
-        if (formatted)
+        if (formatted) {
             formatted->Set(formattedA);
-        else
+        } else {
             formatted = new GooString(formattedA);
+        }
     } else {
         delete formatted;
         formatted = nullptr;
@@ -603,8 +618,9 @@ void Attribute::setFormattedValue(const char *formattedA)
 bool Attribute::checkType(StructElement *element)
 {
     // If an element is passed, tighter type-checking can be done.
-    if (!element)
+    if (!element) {
         return true;
+    }
 
     const TypeMapEntry *elementTypeEntry = getTypeMapEntry(element->getType());
     if (elementTypeEntry && elementTypeEntry->attributes) {
@@ -644,9 +660,9 @@ Attribute *Attribute::parseUserProperty(Dict *property)
     obj = property->lookup("N");
     if (obj.isString()) {
         name.Set(obj.getString());
-    } else if (obj.isName())
+    } else if (obj.isName()) {
         name.Set(obj.getName());
-    else {
+    } else {
         error(errSyntaxError, -1, "N object is wrong type ({0:s})", obj.getTypeName());
         return nullptr;
     }
@@ -688,10 +704,12 @@ StructElement::StructData::~StructData()
     delete id;
     delete title;
     delete language;
-    for (StructElement *element : elements)
+    for (StructElement *element : elements) {
         delete element;
-    for (Attribute *attribute : attributes)
+    }
+    for (Attribute *attribute : attributes) {
         delete attribute;
+    }
 }
 
 StructElement::StructElement(Dict *element, StructTreeRoot *treeRootA, StructElement *parentA, std::set<int> &seen) : type(Unknown), treeRoot(treeRootA), parent(parentA), s(new StructData())
@@ -717,10 +735,11 @@ StructElement::StructElement(const Ref ref, StructTreeRoot *treeRootA, StructEle
 
 StructElement::~StructElement()
 {
-    if (isContent())
+    if (isContent()) {
         delete c;
-    else
+    } else {
         delete s;
+    }
 }
 
 bool StructElement::isBlock() const
@@ -753,8 +772,9 @@ bool StructElement::getPageRef(Ref &ref) const
         return true;
     }
 
-    if (parent)
+    if (parent) {
         return parent->getPageRef(ref);
+    }
 
     return false;
 }
@@ -766,11 +786,13 @@ const char *StructElement::getTypeName() const
 
 const Attribute *StructElement::findAttribute(Attribute::Type attributeType, bool inherit, Attribute::Owner attributeOwner) const
 {
-    if (isContent())
+    if (isContent()) {
         return parent->findAttribute(attributeType, inherit, attributeOwner);
+    }
 
-    if (attributeType == Attribute::Unknown || attributeType == Attribute::UserProperty)
+    if (attributeType == Attribute::Unknown || attributeType == Attribute::UserProperty) {
         return nullptr;
+    }
 
     const Attribute *result = nullptr;
 
@@ -779,8 +801,9 @@ const Attribute *StructElement::findAttribute(Attribute::Type attributeType, boo
         for (unsigned i = 0; i < getNumAttributes(); i++) {
             const Attribute *attr = getAttribute(i);
             if (attributeType == attr->getType()) {
-                if (!result || ownerHasMorePriority(attr->getOwner(), result->getOwner()))
+                if (!result || ownerHasMorePriority(attr->getOwner(), result->getOwner())) {
                     result = attr;
+                }
             }
         }
     } else {
@@ -794,8 +817,9 @@ const Attribute *StructElement::findAttribute(Attribute::Type attributeType, boo
         }
     }
 
-    if (result)
+    if (result) {
         return result;
+    }
 
     if (inherit && parent) {
         const AttributeMapEntry *entry = getAttributeMapEntry(attributeMapAll, attributeType);
@@ -803,8 +827,9 @@ const Attribute *StructElement::findAttribute(Attribute::Type attributeType, boo
         // TODO: Take into account special inheritance cases, for example:
         //       inline elements which have been changed to be block using
         //       "/Placement/Block" have slightly different rules.
-        if (entry->inherit)
+        if (entry->inherit) {
             return parent->findAttribute(attributeType, inherit, attributeOwner);
+        }
     }
 
     return nullptr;
@@ -816,24 +841,29 @@ GooString *StructElement::appendSubTreeText(GooString *string, bool recursive) c
         MarkedContentOutputDev mcdev(getMCID(), stmRef);
         const TextSpanArray &spans(getTextSpansInternal(mcdev));
 
-        if (!string)
+        if (!string) {
             string = new GooString();
+        }
 
-        for (const TextSpan &span : spans)
+        for (const TextSpan &span : spans) {
             string->append(span.getText());
+        }
 
         return string;
     }
 
-    if (!recursive)
+    if (!recursive) {
         return nullptr;
+    }
 
     // Do a depth-first traversal, to get elements in logical order
-    if (!string)
+    if (!string) {
         string = new GooString();
+    }
 
-    for (unsigned i = 0; i < getNumChildren(); i++)
+    for (unsigned i = 0; i < getNumChildren(); i++) {
         getChild(i)->appendSubTreeText(string, recursive);
+    }
 
     return string;
 }
@@ -861,8 +891,9 @@ const TextSpanArray &StructElement::getTextSpansInternal(MarkedContentOutputDev
 static StructElement::Type roleMapResolve(Dict *roleMap, const char *name, const char *curName)
 {
     // Circular reference
-    if (curName && !strcmp(name, curName))
+    if (curName && !strcmp(name, curName)) {
         return StructElement::Unknown;
+    }
 
     Object resolved = roleMap->lookup(curName ? curName : name);
     if (resolved.isName()) {
@@ -870,8 +901,9 @@ static StructElement::Type roleMapResolve(Dict *roleMap, const char *name, const
         return type == StructElement::Unknown ? roleMapResolve(roleMap, name, resolved.getName()) : type;
     }
 
-    if (!resolved.isNull())
+    if (!resolved.isNull()) {
         error(errSyntaxWarning, -1, "RoleMap entry is wrong type ({0:s})", resolved.getTypeName());
+    }
     return StructElement::Unknown;
 }
 
@@ -909,8 +941,9 @@ void StructElement::parse(Dict *element)
 
     // Resolving through RoleMap may leave type as Unknown, e.g. for types
     // which are not present in it, yet they are standard element types.
-    if (type == Unknown)
+    if (type == Unknown) {
         type = nameToType(obj.getName());
+    }
 
     // At this point either the type name must have been resolved.
     if (type == Unknown) {
@@ -980,8 +1013,9 @@ void StructElement::parse(Dict *element)
             } else if (iobj.isInt()) {
                 const int revision = iobj.getInt();
                 // Set revision numbers for the elements previously created.
-                for (unsigned j = attrIndex; j < getNumAttributes(); j++)
+                for (unsigned j = attrIndex; j < getNumAttributes(); j++) {
                     getAttribute(j)->setRevision(revision);
+                }
             } else {
                 error(errSyntaxWarning, -1, "A item is wrong type ({0:s})", iobj.getTypeName());
             }
@@ -1007,8 +1041,9 @@ void StructElement::parse(Dict *element)
                     } else if (iobj.isInt()) {
                         // Set revision numbers for the elements previously created.
                         const int revision = iobj.getInt();
-                        for (unsigned j = attrIndex; j < getNumAttributes(); j++)
+                        for (unsigned j = attrIndex; j < getNumAttributes(); j++) {
                             getAttribute(j)->setRevision(revision);
+                        }
                     } else {
                         error(errSyntaxWarning, -1, "C item is wrong type ({0:s})", iobj.getTypeName());
                     }
@@ -1085,8 +1120,9 @@ StructElement *StructElement::parseChild(const Object *ref, Object *childObj, st
     if (child) {
         if (child->isOk()) {
             appendChild(child);
-            if (ref->isRef())
+            if (ref->isRef()) {
                 treeRoot->parentTreeAdd(ref->getRef(), child);
+            }
         } else {
             delete child;
             child = nullptr;
@@ -1154,8 +1190,9 @@ void StructElement::parseAttributes(Dict *attributes, bool keepExisting)
                                 break;
                             }
                         }
-                        if (exists)
+                        if (exists) {
                             continue;
+                        }
                     }
 
                     if (t != Attribute::Unknown) {
